# Django URL Security


[![PyPI version](https://badge.fury.io/py/django-url-security.svg)](https://badge.fury.io/py/django-url-security)
![versions](https://img.shields.io/pypi/pyversions/django-url-security.svg)
[![GitHub license](https://img.shields.io/github/license/mgancita/django-url-security.svg)](https://github.com/Edrolo/django-url-security/blob/main/LICENSE)


[![Code style: blue](https://img.shields.io/badge/code_style-blue-blue.svg)](https://blue.readthedocs.io/)


Django URL Security provides tests to ensure all the private endpoints in your Django project are private.


- Free software: MIT
- Documentation: https://Edrolo.github.io/django-url-security.


## Features

* TODO

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [`mgancita/cookiecutter-pypackage`](https://mgancita.github.io/cookiecutter-pypackage/) project template.
